@@ -104,7 +104,8 @@ class Swimmer:
 
     @property
     def full_pref_name(self):
-        return f"{self.last_name}, {self.pref_name}"
+        first = self.pref_name if hasattr(self, "pref_name") else self.first_name
+        return f"{self.last_name}, {first}"
 
 class Team:
     name: str
@@ -168,7 +169,7 @@ def read(input):
     for record in output:
         
         if type(record) is TeamIDRecord:
-            if team is not None:
+            if team is not None and swimmer is not None:
                 swimmer.events = events
                 swimmers.append(swimmer)
                 swimmer = None
@@ -303,6 +304,10 @@ def main():
     if input_file == '':
         exit()
 
+    f = open(input_file)
+    meet = read(f.readlines())
+    print(meet)
+
 
 if __name__ == "__main__":
     main()
\ No newline at end of file
